@@ -140,7 +140,7 @@ class RDBService:
         if isinstance(var, int) or isinstance(var, float):
             return str(var)
         elif isinstance(var,Decimal):
-            return str(round(var),2)
+            return str(round(var,2))
         else:
             return '\'{}\''.format(var)
 
